@@ -2,7 +2,7 @@
 #'
 #' Print method for an object of class \code{light}.
 #'
-#' @importFrom dplyr is.tbl
+#' @importFrom utils head
 #' @param x A on object of class \code{light}.
 #' @param ... Further arguments passed from other methods.
 #' @return Invisibly, the input is returned.
@@ -15,12 +15,12 @@
 #' light_effects(fl, v = "Sepal.Length")
 print.light <- function(x, ...) {
   cat("\nI am an object with class(es)", paste(class(x), collapse = ", "), "\n")
-  x_cs <- x[vapply(x, FUN = is.tbl, FUN.VALUE = TRUE)]
+  x_cs <- x[vapply(x, FUN = is.data.frame, FUN.VALUE = TRUE)]
   if (length(x_cs)) {
-    cat("\nTibbles:\n")
+    cat("\ndata.frames (head):\n")
     for (nm in names(x_cs)) {
       cat("\n", nm, "\n")
-      print(x_cs[[nm]], n = 2)
+      print(as.data.frame(head(x_cs[[nm]])))
     }
   }
   invisible(x)
